# nfsquick
#
# Make development over NFS nice and easy by allowing a simple 'bitbake -c
# nfsquick package' command to compile, install and copy to the NFS root in
# one go without needing to rebuild the NFS root from scratch. Of course,
# any files that that are no longer installed in the image won't be removed
# from the NFS root but that hopefully happens rarely.

NFSQUICK_ROOTFS = "${TOPDIR}/${MACHINE}-nfsroot"
NFSQUICK_ROOTFS_cheetah-x11 = "${TOPDIR}/${MACHINE}-root"
NFSQUICK_ROOTFS_panther-x11 = "${TOPDIR}/${MACHINE}-root"

# Install everything from the image to the NFS root
nfsquick_do_copy_to_nfsroot() {
    [ -d "${NFSQUICK_ROOTFS}" ]
    cp -uva ${D}/* "${NFSQUICK_ROOTFS}/"
}

# The tasks that we wish to simulate running for the package
NFSQUICK_FUNCS ?= "do_compile do_install nfsquick_do_copy_to_nfsroot"

python do_nfsquick () {
    for f in (d.getVar('NFSQUICK_FUNCS', True) or '').split():
        bb.build.exec_func(f, d)
}

# If bitbake deems a real compile necessary then it will do it first
# so that any of its pre-requisite tasks get done. This can be handy
# when messing around with git revisions which necessitate a
# do_unpack.
addtask nfsquick after do_compile
do_nfsquick[nostamp] = "1"

